@@ -124,8 +124,8 @@ def nodes_equal(x, y):
         ), f"Ast nodes field names differ : {xname} (of type {type(xval)}) != {yname} (of type {type(yval)})"
         if isinstance(x, ast.Constant) and xname == "kind":
             continue
-        assert type(xval) == type(
-            yval
+        assert (
+            type(xval) == type(yval)
         ), f"Ast nodes fields differ : {xname} (of type {type(xval)}) != {yname} (of type {type(yval)})"
     for xchild, ychild in zip(ast.iter_child_nodes(x), ast.iter_child_nodes(y)):
         assert nodes_equal(xchild, ychild), "Ast node children differs"
